summaryrefslogtreecommitdiff
path: root/src/tools
diff options
context:
space:
mode:
authorGaurav Khanna <gkhanna@microsoft.com>2016-05-09 15:57:44 -0700
committerGaurav Khanna <gkhanna@microsoft.com>2016-05-16 22:22:04 -0700
commit54d45a3f4ed052ddc23d367e2cd46a7c7eb831ea (patch)
tree91c8341a128fe879be2ea5f809ae8356a0d13d7b /src/tools
parent8da89acc3a4f5a57a7346d627ddab32e86b442f4 (diff)
downloadcoreclr-54d45a3f4ed052ddc23d367e2cd46a7c7eb831ea.tar.gz
coreclr-54d45a3f4ed052ddc23d367e2cd46a7c7eb831ea.tar.bz2
coreclr-54d45a3f4ed052ddc23d367e2cd46a7c7eb831ea.zip
Initial change to support System.Private.CoreLib.dll as Core Library.
Diffstat (limited to 'src/tools')
-rw-r--r--src/tools/crossgen/crossgen.cpp18
1 files changed, 9 insertions, 9 deletions
diff --git a/src/tools/crossgen/crossgen.cpp b/src/tools/crossgen/crossgen.cpp
index f174f222a0..8330660ceb 100644
--- a/src/tools/crossgen/crossgen.cpp
+++ b/src/tools/crossgen/crossgen.cpp
@@ -263,7 +263,7 @@ bool StringEndsWith(LPCWSTR pwzString, LPCWSTR pwzCandidate)
#ifdef FEATURE_CORECLR
//
// When using the Phone binding model (TrustedPlatformAssemblies), automatically
// detect which path mscorlib.[ni.]dll lies in.
//
bool ComputeMscorlibPathFromTrustedPlatformAssemblies(SString& pwzMscorlibPath, LPCWSTR pwzTrustedPlatformAssemblies)
{
@@ -282,8 +282,8 @@ bool ComputeMscorlibPathFromTrustedPlatformAssemblies(SString& pwzMscorlibPath,
wszSingleTrustedPath++;
}
- if (StringEndsWith(wszSingleTrustedPath, DIRECTORY_SEPARATOR_STR_W W("mscorlib.dll")) ||
- StringEndsWith(wszSingleTrustedPath, DIRECTORY_SEPARATOR_STR_W W("mscorlib.ni.dll")))
+ if (StringEndsWith(wszSingleTrustedPath, DIRECTORY_SEPARATOR_STR_W CoreLibName_IL_W) ||
+ StringEndsWith(wszSingleTrustedPath, DIRECTORY_SEPARATOR_STR_W CoreLibName_NI_W))
{
pwzMscorlibPath.Set(wszSingleTrustedPath);
SString::Iterator pwzSeparator = pwzMscorlibPath.End();
@@ -324,7 +324,7 @@ void PopulateTPAList(SString path, LPCWSTR pwszMask, SString &refTPAList, bool f
LPCWSTR pwszFilename = folderEnumerator.GetFileName();
if (fCompilingMscorlib)
{
// When compiling mscorlib.dll, no ".ni.dll" should be on the TPAList.
if (StringEndsWith((LPWSTR)pwszFilename, W(".ni.dll")))
{
fAddFileToTPAList = false;
@@ -335,18 +335,18 @@ void PopulateTPAList(SString path, LPCWSTR pwszMask, SString &refTPAList, bool f
// When creating PDBs, we must ensure that .ni.dlls are in the TPAList
if (!fCreatePDB)
{
// Only mscorlib.ni.dll should be in the TPAList for the compilation of non-mscorlib assemblies.
if (StringEndsWith((LPWSTR)pwszFilename, W(".ni.dll")))
{
- if (!StringEndsWith((LPWSTR)pwszFilename, W("mscorlib.ni.dll")))
+ if (!StringEndsWith((LPWSTR)pwszFilename, CoreLibName_NI_W))
{
fAddFileToTPAList = false;
}
}
}
- // Ensure that mscorlib.dll is also not on the TPAlist for this case.
- if (StringEndsWith((LPWSTR)pwszFilename, W("mscorlib.dll")))
+ // Ensure that CoreLib's IL version is also not on the TPAlist for this case.
+ if (StringEndsWith((LPWSTR)pwszFilename, CoreLibName_IL_W))
{
fAddFileToTPAList = false;
}
@@ -867,7 +867,7 @@ int _cdecl wmain(int argc, __in_ecount(argc) WCHAR **argv)
}
// Are we compiling mscorlib.dll?
- bool fCompilingMscorlib = StringEndsWith((LPWSTR)pwzFilename, W("mscorlib.dll"));
+ bool fCompilingMscorlib = StringEndsWith((LPWSTR)pwzFilename, CoreLibName_IL_W);
if (fCompilingMscorlib)
dwFlags &= ~NGENWORKER_FLAGS_READYTORUN;
@@ -263,7 +263,7 @@ bool StringEndsWith(LPCWSTR pwzString, LPCWSTR pwzCandidate)
//
// When using the Phone binding model (TrustedPlatformAssemblies), automatically
-// detect which path mscorlib.[ni.]dll lies in.
+// detect which path CoreLib.[ni.]dll lies in.
//
bool ComputeMscorlibPathFromTrustedPlatformAssemblies(SString& pwzMscorlibPath, LPCWSTR pwzTrustedPlatformAssemblies)
@@ -324,7 +324,7 @@ void PopulateTPAList(SString path, LPCWSTR pwszMask, SString &refTPAList, bool f
if (fCompilingMscorlib)
{
- // When compiling mscorlib.dll, no ".ni.dll" should be on the TPAList.
+ // When compiling CoreLib, no ".ni.dll" should be on the TPAList.
if (StringEndsWith((LPWSTR)pwszFilename, W(".ni.dll")))
{
@@ -335,18 +335,18 @@ void PopulateTPAList(SString path, LPCWSTR pwszMask, SString &refTPAList, bool f
if (!fCreatePDB)
{
- // Only mscorlib.ni.dll should be in the TPAList for the compilation of non-mscorlib assemblies.
+ // Only CoreLib's ni.dll should be in the TPAList for the compilation of non-mscorlib assemblies.
if (StringEndsWith((LPWSTR)pwszFilename, W(".ni.dll")))
{